@@ -66,7 +66,11 @@ class Client(object):
             pre = ''
         
         try:
-            m = mode or int(self.cfg.mode)
+            # m = mode or int(self.cfg.mode)
+            if mode == None:
+                m = int(self.cfg.mode)
+            else:
+                m = int(mode)
         except Exception:
             m = ''
         
