@@ -22,8 +22,8 @@ class SimpleUpload(object):
     def __init__(self,url):
         self.url = url
         session = requests.Session()
-        session.mount('http://', HTTPAdapter(max_retries=Config.connection_retries))
-        session.mount('https://', HTTPAdapter(max_retries=Config.connection_retries))
+        session.mount('http://', HTTPAdapter(max_retries=int(Config.connection_retries)))
+        session.mount('https://', HTTPAdapter(max_retries=int(Config.connection_retries)))
         global _session
         _session = session
 
@@ -50,9 +50,15 @@ class SimpleUpload(object):
             headers['Connection'] = 'close'
         try:
             if cfg.isverify:
-                r = _session.post(url=url, headers=headers, data=encoder, verify=True)
+                if cfg.returnUrl:
+                    r = _session.post(url=url, headers=headers, data=encoder, verify=True,allow_redirects=False)
+                else:
+                    r = _session.post(url=url, headers=headers, data=encoder, verify=True)
             else:
-                r = _session.post(url=url, headers=headers, data=encoder, verify=False)
+                if cfg.returnUrl:
+                    r = _session.post(url=url, headers=headers, data=encoder, verify=False,allow_redirects=False)
+                else:
+                    r = _session.post(url=url, headers=headers, data=encoder, verify=False)
         except Exception as e:
             f.close()
             debug('Request url:' + url)
@@ -64,7 +70,10 @@ class SimpleUpload(object):
         f.close()
         try:
             r_header = {'x-reqid': r.headers['x-reqid']}
-            return r.status_code,r.text,r_header
+            if r.status_code == 303:
+                return r.status_code, r.headers['Location'], r_header
+            else:
+                return r.status_code, r.text, r_header
         except:           
             return r.status_code,r.text
 
